@@ -1,7 +1,7 @@
 globalVariables(c("."))
 
 
-#to do: is het mogelijk dat check op onmogelijke toetspaden een warning wordt?
+#to~do: is het mogelijk dat check op onmogelijke toetspaden een warning wordt?
 
 
 #' Define routing rules
@@ -76,7 +76,7 @@ mst_rules = function(...)
   }
   gj = function(x)
   {
-    x = t(x[c(T,F,T,F,T,F,F,F,F)])
+    x = t(x[c(TRUE,FALSE,TRUE,FALSE,TRUE,FALSE,FALSE,FALSE,FALSE)])
 
     do.call(bind_rows,
             lapply(split(x, ceiling(seq_along(x)/3)),
@@ -276,7 +276,7 @@ alter_scoring_rules_mst = function(db, rules)
   invisible(NULL)
 }
 
-# to do: simulation in example can be done with dexter
+
 #' Define a new multi stage test
 #' 
 #' Before you can enter data, dexterMST needs to know the design of your test. 
@@ -312,76 +312,48 @@ alter_scoring_rules_mst = function(db, rules)
 #' @examples
 #' # extended example
 #' # we: 
-#' # 1) simulate complete data
-#' # 2) cut it up according to an MST design
+#' # 1) define an mst design
+#' # 2) simulate mst data
 #' # 3) create a project, enter scoring rules and define the MST test
 #' # 4) do an analysis
 #' 
 #' library(dplyr)
-#' sim_RM = function(theta,delta)
-#' { 
-#'   nP=length(theta)
-#'   dat=matrix(0,nP,length(delta))
-#'   for (i in 1:length(delta)) dat[,i]=1*(rlogis(nP,0,1)<=(theta-delta[i]))
-#'   return(dat)
-#' }
 #' 
-#' ## Simulate data set with all routing
-#' scoring_rules = data.frame(item_id=rep(sprintf("item%02.0f",1:70), each=2),
-#'                            response=rep(0:1,times=70),
-#'                            item_score=rep(0:1,times=70))
+#' items = data.frame(item_id=sprintf("item%02i",1:70), item_score=1, delta=sort(runif(70,-1,1)))
+#'
+#' design = data.frame(item_id=sprintf("item%02i",1:70),
+#'                     module_id=rep(c('M4','M2','M5','M1','M6','M3', 'M7'),each=10))
+#'
+#' routing_rules = routing_rules = mst_rules(
+#'  `124` = M1[0:5] --+ M2[0:10] --+ M4, 
+#'  `125` = M1[0:5] --+ M2[11:15] --+ M5,
+#'  `136` = M1[6:10] --+ M3[6:15] --+ M6,
+#'  `137` = M1[6:10] --+ M3[16:20] --+ M7)
+#'
+#' theta = rnorm(3000)
+#'
+#' dat = sim_mst(items, theta, design, routing_rules,'all')
+#' dat$test_id='sim_test'
+#' dat$response=dat$item_score
 #' 
 #' 
-#' design = data.frame(item_id=sprintf("item%02.0f",1:70),
-#'                     module_id=rep(c('M4','M2','M5','M1','M6','M3', 'M7'),times=rep(10,7)),
-#'                     item_position=rep(1:10,7))
-#' 
-#' delta = sort(runif(70,-1,1))
-#' theta = rnorm(2000,0,1)
-#' 
-#' data = data.frame(sim_RM(theta,delta))
-#' colnames(data) = sprintf("item%02.0f",1:70)
-#' data$person_id = 1:nrow(data)
-#' 
-#' scoring_rules = data.frame(item_id=rep(sprintf("item%02.0f",1:70), each=2),
-#'                            response=rep(0:1,times=70),
-#'                            item_score=rep(0:1,times=70))
-#' 
-#' design = data.frame(item_id=sprintf("item%02.0f",1:70),
-#'                     module_id=rep(c('M4','M2','M5','M1','M6','M3', 'M7'),times=rep(10,7)),
-#'                     item_position=rep(1:10,7))
+#' scoring_rules = data.frame(
+#'   item_id = rep(items$item_id,2), 
+#'   item_score= rep(0:1,each=nrow(items)),
+#'   response= rep(0:1,each=nrow(items))) # dummy respons
+#'   
 #' 
 #' db = create_mst_project(":memory:")
 #' add_scoring_rules_mst(db, scoring_rules)
-#' 
-#' 
-#' routing_rules = mst_rules(
-#'   `124` = M1[0:5] --+ M2[0:10] --+ M4, 
-#'   `125` = M1[0:5] --+ M2[11:15] --+ M5,
-#'   `136` = M1[6:10] --+ M3[6:15] --+ M6,
-#'   `137` = M1[6:10] --+ M3[16:20] --+ M7)
-#' 
+#'
 #' create_mst_test(db,
 #'                 test_design = design,
 #'                 routing_rules = routing_rules,
-#'                 test_id = 'RU',
+#'                 test_id = 'sim_test',
 #'                 routing = "all")
 #' 
-#' subset(data,(rowSums(data[,31:40])<=5)&(rowSums(data[,c(31:40,11:20)])<=10),
-#'        select=c(item31:item40, item11:item20, item01:item10, person_id)) %>%
-#'   add_booklet_mst(db,.,booklet_id='124',test_id='RU')
+#' add_response_data_mst(db, dat)
 #' 
-#' subset(data,(rowSums(data[,31:40])<=5)&(rowSums(data[,c(31:40,11:20)])>10),
-#'        select=c(item31:item40, item11:item20, item21:item30,person_id)) %>%
-#'   add_booklet_mst(db,.,booklet_id='125',test_id='RU')
-#' 
-#' subset(data,(rowSums(data[,31:40])>5)&(rowSums(data[,c(31:40,51:60)])<=15),
-#'        select=c(item31:item40,item51:item60, item41:item50, person_id)) %>%
-#'   add_booklet_mst(db,.,booklet_id='136',test_id='RU')
-#' 
-#' subset(data,(rowSums(data[,31:40])>5)&(rowSums(data[,c(31:40,51:60)])>15),
-#'        select=c(item31:item40, item51:item60, item61:item70, person_id)) %>%
-#'   add_booklet_mst(db,.,booklet_id='137',test_id='RU')
 #' 
 #' design_plot(db)
 #' 
@@ -390,7 +362,7 @@ alter_scoring_rules_mst = function(db, rules)
 #' head(coef(f))
 #' 
 #' abl = ability(get_responses_mst(db), f) %>%
-#'    inner_join(tibble(person_id=as.character(1:2000), theta.sim=theta), by='person_id')
+#'    inner_join(tibble(person_id=as.character(1:3000), theta.sim=theta), by='person_id')
 #' 
 #' plot(abl$theta, abl$theta.sim)   
 #' 
@@ -402,6 +374,14 @@ create_mst_test = function(db, test_design, routing_rules, test_id, routing = c(
 {
   routing = match.arg(routing)
   
+  if(!'item_position' %in% test_design)
+  {
+    test_design = test_design %>%
+      group_by(.data$module_id) %>%
+      mutate(item_position=row_number()) %>%
+      ungroup()
+  }
+  
   test_design = test_design %>% 
     select(.data$item_id, .data$module_id, .data$item_position) %>%
     mutate_if(is.factor, as.character)
@@ -534,13 +514,12 @@ create_mst_test = function(db, test_design, routing_rules, test_id, routing = c(
                 mutate(test_id = test_id) %>% 
                 semi_join(bd, by='module_id') %>%
                 select(.data$test_id, .data$module_id, .data$item_id,	.data$item_position))
-    
+    bd$test_id = test_id
     dbExecute(db, 
         'INSERT INTO Booklet_design(test_id, booklet_id,
     	                              module_id, module_nbr, module_exit_score_min,	module_exit_score_max) 
           VALUES(:test_id, :booklet_id, :module_id, :module_nbr, :exit_min, :exit_max);',
-        add_column(bd, test_id=test_id) %>% 
-          select(.data$test_id, .data$booklet_id, .data$module_id, .data$module_nbr, .data$exit_min, .data$exit_max))
+        select(bd,.data$test_id, .data$booklet_id, .data$module_id, .data$module_nbr, .data$exit_min, .data$exit_max))
   })  
  invisible(NULL)
 }
