@@ -1,4 +1,4 @@
-## ----setup, include=FALSE------------------------------------------------
+## ----setup, include=FALSE-----------------------------------------------------
 library(knitr)
 opts_chunk$set(fig.align='center',fig.width=5,fig.height=5, dev='CairoPNG') 
 
@@ -22,7 +22,7 @@ library(mirt)
 library(RSQLite)
 library(ggplot2)
 
-## ----zwitsermaris, include=FALSE-----------------------------------------
+## ----zwitsermaris, include=FALSE----------------------------------------------
 sim_RM = function(theta,delta)
 {
   nP=length(theta)
@@ -67,7 +67,7 @@ design = data.frame(module_id = rep(c('Mod_2','Mod_1','Mod_3'), times=c(20,10,20
 create_mst_test(db,
                 test_design = design,
                 routing_rules = routing_rules,
-                test_id = 'ZwitserMaris')
+                test_id = 'ZwitserMaris',routing='last')
 
 
 
@@ -84,58 +84,60 @@ add_booklet_mst(db, bk1, test_id = 'ZwitserMaris', booklet_id = 'easy')
 add_booklet_mst(db, bk2, test_id = 'ZwitserMaris', booklet_id = 'hard')
 
 
-## ---- echo=FALSE, out.width=300,out.height=300, fig.width=5,fig.height=5----
+## ---- echo=FALSE, out.width=300,out.height=300, fig.width=5,fig.height=5------
 design_plot(db,vertex.size=70,vertex.size2=30, vertex.label.cex=1.5, edge.label.cex=1.5)
 
-## ---- eval=FALSE---------------------------------------------------------
+## ---- eval=FALSE--------------------------------------------------------------
 #  db = create_mst_project(":memory:")
 
-## ---- echo=FALSE---------------------------------------------------------
+## ---- echo=FALSE--------------------------------------------------------------
 scoring_rules %>% slice(1:8) %>% kable(caption='data.frame scoring_rules', row.names=FALSE)
 
-## ---- eval=FALSE---------------------------------------------------------
+## ---- eval=FALSE--------------------------------------------------------------
 #  add_scoring_rules_mst(db, scoring_rules)
 
-## ---- echo=FALSE---------------------------------------------------------
+## ---- echo=FALSE--------------------------------------------------------------
 design %>% slice(1:8) %>% kable(caption='data.frame design')
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 routing_rules = mst_rules(
   easy = Mod_1[0:5] --+ Mod_2, 
   hard = Mod_1[6:10] --+ Mod_3)
 
-## ---- eval=FALSE---------------------------------------------------------
+## ---- eval=FALSE--------------------------------------------------------------
 #  create_mst_test(db,
 #                  test_design = design,
 #                  routing_rules = routing_rules,
 #                  test_id = 'ZwitserMaris')
 
-## ---- echo=FALSE---------------------------------------------------------
+## ---- echo=FALSE--------------------------------------------------------------
 bk1[1:4,1:6] %>% mutate(item06='...') %>% kable(caption='example data in wide format (`bk1` below)', row.names=FALSE)
 
-## ---- eval=FALSE---------------------------------------------------------
+## ---- eval=FALSE--------------------------------------------------------------
 #  add_booklet_mst(db, bk1, test_id = 'ZwitserMaris', booklet_id = 'easy')
 #  add_booklet_mst(db, bk2, test_id = 'ZwitserMaris', booklet_id = 'hard')
 
-## ----fig.width=8,fig.height=4,out.width='100%',par=list(mfrow=c(1,2))----
+## ----fig.width=8,fig.height=4,out.width='100%',par=list(mfrow=c(1,2))---------
 fi = fit_inter_mst(db, test_id = 'ZwitserMaris', booklet_id = 'hard')
 
 plot(fi, item_id='item21')
 plot(fi, item_id='item45')
 
-## ---- results='hide'-----------------------------------------------------
+## ---- results='hide'----------------------------------------------------------
 f = fit_enorm_mst(db)
 
 coef(f)
 
-## ---- echo=FALSE---------------------------------------------------------
+## ---- echo=FALSE--------------------------------------------------------------
 coef(f) %>% slice(1:8) %>% kable(caption='some item parameters fit on multi stage data')
 
 
-## ---- echo=FALSE, message=FALSE, warning=FALSE,results='hide'------------
+## ---- echo=FALSE, message=FALSE, warning=FALSE,results='hide'-----------------
 ## add an arbitrary item property
-item_domain=c(sample(c("A", "B", "C"), 20, replace = T), rep("B", 10), sample(c("A", "B", "C"), 20, replace = T))
-item_type = data.frame(item_id = get_items_mst(db), item_domain=item_domain)
+
+item_type = get_items_mst(db)
+item_type$item_domain = c(sample(c("A", "B", "C"), 20, replace = T), rep("B", 10), sample(c("A", "B", "C"), 20, replace = T))
+
 add_item_properties_mst(db, item_type)
 
 prof = profile_tables_mst(f, dbReadTable(db, 'items'), 'item_domain')
@@ -151,20 +153,22 @@ observed = dbGetQuery(db,
   group_by(booklet_id, person_id, item_domain) %>% 
   summarise(observed_score = sum(item_score)) %>% 
   group_by(booklet_id, person_id) %>% 
-  mutate(sumScore = sum(observed_score))
+  mutate(booklet_score = sum(observed_score))
 ## average
 observed_smooth = observed %>%
-  group_by(booklet_id, sumScore, item_domain) %>%
+  group_by(booklet_id, booklet_score, item_domain) %>%
   summarise(observed_score = mean(observed_score)) %>%
   ungroup()
 ## Ignore the MST design and use dexter
 prof_naive = dexter::profile_tables(f, dbReadTable(db, 'items'), 'item_domain') %>%
-  mutate(booklet_id=gsub('^\\w+\\.','',booklet_id))
+  mutate(booklet_id=gsub('^\\w+-','',booklet_id))
+
+
 ## plot the results
 ggplot(full_join(prof, prof_naive, 
-                 by=c('sumScore','booklet_id','item_domain')) %>%
-         full_join(observed_smooth, by=c('sumScore','booklet_id','item_domain')),
-       aes(x = sumScore, y = expected_domain_score.x, colour = item_domain)) +
+                 by=c('booklet_score','booklet_id','item_domain')) %>%
+         full_join(observed_smooth, by=c('booklet_score','booklet_id','item_domain')),
+       aes(x = booklet_score, y = expected_domain_score.x, colour = item_domain)) +
   geom_line(size=0.3) + 
   geom_point(aes(y=observed_score), size = 0.1) +
   facet_grid(booklet_id~.,scale='free_y') + 
@@ -173,22 +177,22 @@ ggplot(full_join(prof, prof_naive,
   labs(y='domain score', x ='test score')
 
 
-## ---- results='hide'-----------------------------------------------------
+## ---- results='hide'----------------------------------------------------------
 abl = ability_tables(f, method='MLE')
 abl
 
-## ---- echo=FALSE---------------------------------------------------------
+## ---- echo=FALSE--------------------------------------------------------------
 abl %>% slice(1:10) %>% kable(caption='score transformation table (abl)')
 
 
-## ----eval=FALSE----------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  f2 = fit_enorm_mst(db, item_id != 'item21')
 
-## ----echo=FALSE----------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 plot(density(theta),bty='n',main='true distribution of ability',xlab=expression(theta))
 
 
-## ---- echo = FALSE,fig.height=3, fig.width=7, results='hide'-------------
+## ---- echo = FALSE,fig.height=3, fig.width=7, results='hide'------------------
 
 # Correct cml with dexterMST
 delta.cml.mst = coef(f)$beta
@@ -226,37 +230,37 @@ plot(delta, delta.mml+mean(delta) - mean(delta.mml),
      main="MML", ylab = "estimate",xlim=lim,ylim=lim)
 abline(0,1,lty=3)
 
-## ---- eval=FALSE---------------------------------------------------------
+## ---- eval=FALSE--------------------------------------------------------------
 #  tia_tables(get_responses_mst(db))$testStats %>%
 #    select(booklet_id, meanP)
 
-## ---- echo=TRUE----------------------------------------------------------
+## ---- echo=TRUE---------------------------------------------------------------
 tia_tables(get_responses_mst(db))$testStats %>%
   select(booklet_id, meanP) %>%
   kable(caption='mean item correct')
 
 
-## ---- par=list(bty='l')--------------------------------------------------
+## ---- par=list(bty='l')-------------------------------------------------------
 rsp_data = get_responses_mst(db)
 pv = plausible_values(rsp_data, parms = f)
 
 plot(density(pv$PV1), main='plausible value distribution', xlab='pv')
 
-## ---- out.width=300,out.height=300, fig.width=5,fig.height=5-------------
+## ---- out.width=300,out.height=300, fig.width=5,fig.height=5------------------
 design_plot(db, item_id!="item21")
 
-## ---- echo=FALSE, eval=FALSE---------------------------------------------
+## ---- echo=FALSE, eval=FALSE--------------------------------------------------
 #  db = open_mst_project("/home/timo/Documents/statlib/bitbucket/acet_mst_2018_8001.db")
 #  dbExecute(db, "alter table tests add column routing text not null default 'all'")
 #  f = fit_enorm_mst(db, test_id=="RRA1")
 #  design_plot(db,test_id=="RRA1")
 
-## ---- eval=FALSE---------------------------------------------------------
+## ---- eval=FALSE--------------------------------------------------------------
 #  lin.test_design = data.frame(module_id='mod1', item_id=paste('item',1:30), item_positon = 1:30)
 #  lin.rules = mst_rules(lin.booklet = mod1)
 #  create_mst_test(db, lin.test_design, lin.rules, test_id = 'linear test')
 #  
 
-## ---- echo=FALSE---------------------------------------------------------
+## ---- echo=FALSE--------------------------------------------------------------
 close_mst_project(db)
 
